"""
 PretendFolderContainer product test development.
 Peter Bengtsson, Fry-IT, 2002
"""

# Python
import string, os

# Zope
from Globals import MessageDialog, DTMLFile, \
                    package_home, InitializeClass, Persistent
from OFS import SimpleItem, Folder

# PFC = Pretend Folder Container


manage_addPFCForm = DTMLFile('addPFCForm', globals())

def manage_addPFC(dispatcher, id, title, REQUEST=None):
    """ Create Pretend Folder Container """
    dest = dispatcher.Destination()
    pfc = PretendFolderContainer(id, title)
    dest._setObject(id, pfc)
    self = dest._getOb(id)

    
    if REQUEST is not None:
        return MessageDialog(title="Pretend Folder Container added",
              message="Pretend Folder Container added", 
              action=REQUEST['URL1']+'/manage_main')


class PretendFolderContainer(Folder.Folder,Persistent):
    """ PretendFolderContainer class """

    meta_type = "Pretend Folder Container"

    manage_options = Folder.Folder.manage_options +\
                  ({'label': 'Directories', 'action': 'view_directories'},
                   )


    def __init__(self, id, title):
        """ Just one special property """
        self.directory_ids = {}
        self.id = id
        self.title = title


    view_directories = DTMLFile('view_directories', globals())

    def getPFCDirectories(self):
        """ return the property itself """
        return self.directory_ids

    def getPFCDirectory(self, id):
        """ return the value by the key """
        return self.directory_ids[id]
    
    
    def addPFCDirectory(self, id, name):
        """ add item to directory_ids """
        if self.directory_ids.has_key(id):
            raise "KeyError", "Directory id already taken"
        else:
            self.updatePFCDirectory(id, name)

    def addPFCDirectories(self, dictionary):
        """ add many items """
        for id, name in dictionary.items():
            self.addPFCDirectory(id, name)

    def updatePFCDirectory(self, id, name):
        """ update item in directory_ids """
        _directory_ids = self.directory_ids
        _directory_ids[id]=name
        self.directory_ids=_directory_ids

    def updatePFCDirectories(self, dictionary):
        """ update many items """
        for id, name in dictionary.items():
            self.updatePFCDirectory(id, name)

    def removePFCDirectory(self, id):
        """ remove item from directory_ids """
        _directory_ids = self.directory_ids
        del _directory_ids[id]
        self.directory_ids = _directory_ids

    def removePFCDirectories(self, ids):
        """ remove several items from directory_ids """
        if type(ids)!=type([]):
            ids = [ids]
        for id in ids:
            self.removePFCDirectory(id)

    def has_pfcdirectory(self, name=None, id=None):
        """ Check if a directory is defined """
        if id is not None:
            return self.directory_ids.has_key(id)
        else:
            return name in self.directory_ids.values()
        

    def update_or_addPFCDirectory(self, id, name):
        """ Call if you don't care if an item is in or not.
            If not already in, it's added. If already added
            it's updated.
        """
        self.updatePFCDirectory(id, name)

    def update_or_addPFCDirectories(self, dictionary):
        """ update or add many items """
        for id, name in dictionary.items():
            self.update_or_addPFCDirectory(id, name)

    def clearPFCDirectories(self):
        """ clear everything """
        self.directory_ids = {}

    def getPFCIdByName(self, name):
        """ get the id key from a name """
        for k,v in self.directory_ids.items():
            if v==name:
                return k
        else:
            return None


    def __before_publishing_traverse__(self, object, request):
        """ sort things about before publishing object """
        stack = request['TraversalRequestNameStack']

	# Daring test
	stack.reverse()
	stack_path = '/'.join(stack)

	if self.has_pfcdirectory(stack_path):
	    request.set('popped', self.getPFCIdByName(stack_path))

	    for i in range(len(stack)):
		stack.pop()

	else:
	    stack.reverse()

	if hasattr(self, 'processPopped'):
            getattr(self, 'processPopped')()


InitializeClass(PretendFolderContainer)





